/** -*- Mode: C++; tab-width: 4 -*-
 * vim: sw=4 ts=4:
 *
 * Gnome Apt progress indicator dialog class
 *
 * 	(C) 1998 Havoc Pennington <hp@pobox.com>
 * 	    2003 Filip Van Raemdonck <mechanix@debian.org>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 *
 * 	$Id$
 *
 **/

#ifndef GNOME_APT_DIALOGPROGRESS_H
#define GNOME_APT_DIALOGPROGRESS_H

#include <gtk/gtkwidget.h>
#include <apt-pkg/progress.h>

class OpDialogProgress : public OpProgress {
private:
  GtkWidget* dialog_;
  GtkWidget* bar_;
  GtkWidget* label_;
 
protected:
  virtual void Update();
  
public:
	OpDialogProgress (GtkWidget*);

	virtual void Done (void);
	OpDialogProgress* This (void) { return this; }
};

#endif
